{-|
Module      : PUBMED.ServantClientLogging
Description : PubMed API integration
Copyright   : (c) CNRS, 20198
License     : AGPL + CECILL v3
Maintainer  : team@gargantext.org
Stability   : experimental
Portability : POSIX
-}
module PUBMED.ServantClientLogging where

import Debug.Trace (trace)
import Network.HTTP.Types
import Servant.Client (ClientEnv(..))
import Servant.Client.Core.Request (RequestF(..))
import qualified Data.Binary.Builder as DBB


addLoggingToClientEnv :: ClientEnv -> ClientEnv
addLoggingToClientEnv env@(ClientEnv { makeClientRequest = mcr }) = env { makeClientRequest }
  where
    makeClientRequest baseUrl req =
      trace ("req: " <> showRequestPath req <> " " <> show (fmap sanitiseQueryItem $ requestQueryString req)) $ mcr baseUrl req
    showRequestPath req =
      show $ DBB.toLazyByteString $ requestPath req

    sanitiseQueryItem :: QueryItem -> QueryItem
    sanitiseQueryItem (k, mb_v)
      | k == "api_key"
      = (k, Just "*****")
      | otherwise
      = (k, mb_v)
